@@ -1,9 +1,10 @@
 from . import hellomsg
-import pygame
 from .fps_clock import FPS
 from .utils import *
 from .frame import GFrame
 from .image import GImage
 from .label import GLabel
+from .rect import GRect
+from .simple_button import GSimpleButton
 
 del hellomsg
